@@ -26,6 +26,12 @@ KeePassXmlStreamReader::KeePassXmlStreamReader(QObject *parent) :
 {
 }
 
+void KeePassXmlStreamReader::addEntry(){
+    qDebug("Entry: %s, %s, %s", entryTitle.toUtf8().constData(), userName.toUtf8().constData(), comment.toUtf8().constData());
+    entries << Entry(entryTitle, groupTitle, userName, password, QString(url + "\n" + comment));
+    resetEntry();
+}
+
 QList<Entry> KeePassXmlStreamReader::openFileForImport(){
     qDebug("Entering openFileForImport...");
     entries.clear();
@@ -54,15 +60,69 @@ QList<Entry> KeePassXmlStreamReader::openFileForImport(){
 void KeePassXmlStreamReader::parseFile(){
     while(xmlReader.readNextStartElement()){
         if(xmlReader.name() == "database"){
-            qDebug("Found database.");
+            qDebug("Found database tag. Assuming KeePassX file format. Continuing with KeePassX specific parsing...");
             parseDatabase();
-        }else{
+        }else if(xmlReader.name() == "PwmanXmlList"){
+            qDebug("Found PwmanXmlList tag. Assuming pwman3 file format. Continuing with pwman3 specific parsing...");
+            parsePwmanList();
+        }
+        else{
             qErrnoWarning("No Database found!");
         }
     }
     qDebug("Leaving parseFile...");
 }
 
+/*
+ * Begin: Parse pwman3 XML Files.
+ */
+void KeePassXmlStreamReader::parsePwmanList(){
+    groupTitle = "pwman3";
+
+    while(xmlReader.readNextStartElement()){
+        if(xmlReader.name() == "Node"){
+            qDebug("Found Node in pwman3 XML list.");
+            parseNode();
+        }else{
+            qDebug("Skipping pwman3 XML list child element: %s", xmlReader.name().toString().toUtf8().constData());
+            xmlReader.skipCurrentElement();
+        }
+    }
+    qDebug("Leaving parsePwmanList...");
+}
+void KeePassXmlStreamReader::parseNode(){
+    while(xmlReader.readNextStartElement()){
+        if(xmlReader.name() == "username"){
+            userName = xmlReader.readElementText();
+        }else if(xmlReader.name() == "password"){
+            password = xmlReader.readElementText();
+        }else if(xmlReader.name() == "url"){
+            url = xmlReader.readElementText();
+        }else if(xmlReader.name() == "notes"){
+            do{
+                if(xmlReader.isCharacters()){
+                    comment += xmlReader.text().toString();
+                }else if(xmlReader.isStartElement() && xmlReader.name() == "br"){
+                    comment += "\n";
+                }
+                xmlReader.readNext();
+            }while (xmlReader.name() != "notes");
+        }else{
+            qDebug("Skipping Node child element: %s", xmlReader.name().toString().toUtf8().constData());
+            xmlReader.skipCurrentElement();
+        }
+    }
+    entryTitle = userName + " " + url;
+    addEntry();
+    qDebug("Leaving parseNode...");
+}
+/*
+ * End: Parse pwman3 XML Files.
+ */
+
+/*
+ * Begin: Parse KeePassX XML Files.
+ */
 void KeePassXmlStreamReader::parseDatabase(){
     resetMembers();
     while(xmlReader.readNextStartElement()){
@@ -76,7 +136,6 @@ void KeePassXmlStreamReader::parseDatabase(){
     }
     qDebug("Leaving parseDatabase...");
 }
-
 void KeePassXmlStreamReader::parseGroup(){
     while(xmlReader.readNextStartElement()){
         if(xmlReader.name() == "title"){
@@ -96,7 +155,6 @@ void KeePassXmlStreamReader::parseGroup(){
     resetMembers();
     qDebug("Leaving parseGroup...");
 }
-
 void KeePassXmlStreamReader::parseEntry(){
     while(xmlReader.readNextStartElement()){
         QStringRef name = xmlReader.name();
@@ -122,11 +180,12 @@ void KeePassXmlStreamReader::parseEntry(){
             xmlReader.skipCurrentElement();
         }
     }
-    qDebug("Entry: %s, %s, %s", entryTitle.toUtf8().constData(), userName.toUtf8().constData(), comment.toUtf8().constData());
-    entries << Entry(entryTitle, groupTitle, userName, password, QString(url + "\n" + comment));
-    resetEntry();
+    addEntry();
     qDebug("Leaving parseEntry...");
 }
+/*
+ * End: Parse KeePassX XML Files.
+ */
 
 void KeePassXmlStreamReader::resetMembers(){
     groupTitle = (groupTitleStack.isEmpty()) ? "" : groupTitleStack.takeLast();
