@@ -37,10 +37,6 @@ public:
         clipboard->setText(text, QClipboard::Selection);
     }
 
-signals:
-
-public slots:
-
 private:
     QClipboard *clipboard;
 
